.. pyimgren documentation master file, created by
   sphinx-quickstart on Thu Oct 25 10:07:47 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyimgren |version| documentation!
============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   install
   usage
   api
   testing
   localisation
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
